******************************************************************************************
******************************************************************************************
**** Code files for "How Elastic Are Preferences for Redistribution:                 *****
**** Evidence from Randomized Survey Experiments."                                   *****                  
******************************************************************************************
*** Authors: Ilyana Kuziemko, Michael Norton, Emmanuel Saez and Stefanie Stantcheva  *****
*** Date: November 2014                                                              *****
*** For questions and comments please contact Stefanie Stantcheva                    *****
*** sstantcheva@fas.harvard.edu                                                      *****
******************************************************************************************
******************************************************************************************


******************************************************************************************
******* Follow up Experiment                             
******************************************************************************************
******* input: Inequality_AER_Followup.dta, data from the original and follow up wave
******* output: main paper and appendix tables for all follow up results
******************************************************************************************

* Modify the path here to the folder where you placed the datasets

* Please check the variable labels and value labels, which show the survey question asked
* and the answer choices given to respondents.

cd "/Users/stefaniestantcheva/Dropbox/inequality/AER_revision2/data/"

clear
set mem 500m
set more off

cap log close
log using ineq_followup.log, replace

use Inequality_AER_Followup.dta, clear

gen obama08=(party2008 ==1) if party2008~=.

******************************************************************************************
********* Definition of outcome variables 
******************************************************************************************

gen inc_mill=tax_millionaires==1 if tax_millionaires~=.

gen ineq_inc_yes=inequality_increase==3 if inequality_increase~=.
gen ineq_vs=inequality_problem==5 if inequality_problem~=. 

gen democrat12=(party2012==1) if party2012~=.
gen republican12 = (party2012 == 2) if party2012~=.

gen deserving_yes=deserving==3 if deserving~=. 

****Note "_s2" denotes "survey 2," the follow-up survey

gen inc_mill_s2=tax_millionaires_s2==1 if tax_millionaires_s2~=.

gen democrat12_s2=(party2012_s2==1) if party2012_s2~=.

gen republican12_s2 = (party2012_s2 == 2) if party2012_s2~=.

gen deserving_yes_s2 =deserving_s2 ==3 if deserving_s2 ~=. 

gen tax_redistr_s2=taxes_goal_s2==3 if taxes_goal_s2~=. 

gen inc_estate=estate_tax==3 if estate_tax~=.
gen inc_estate_s2=estate_tax_s2==3 if estate_tax_s2~=.

gen ineq_inc_yes_s2=inequality_increase_s2==3 if inequality_increase_s2~=.
gen ineq_vs_s2=inequality_problem_s2==5 if inequality_problem_s2~=. 

tab trust_government
tab trust_government_s2

replace trust_government=5-trust_government
replace trust_government_s2=5-trust_government_s2

gen trust_gov_yes=trust_government>2 if trust_government~=. 
gen trust_gov_yes_s2=trust_government_s2>2 if trust_government_s2~=. 

*******Check on selection into following up ;

gen followup=inc_mill_s2~=. 
gen male=gender==1
gen white=ethn==1 if ethn~=.
gen ft_emp=employment==1 if employment~=.
gen married=marital==2 if marital~=.
gen native=usborn==1 if usborn~=.
gen black=ethnic==2 if ethnic~=.
gen hisp=ethnic==3 if ethnic~=.
gen asian=ethnic==4 if ethnic~=.
gen college=educ>5 if educ~=.
gen fulltime=employ==1 if employ~=.
gen unemp=employ==4 if employ~=.
gen student=employ==5 if employ~=.
gen nilf=employ==6 if employ~=.
****hhincome has a lot of missings, so instead of controlling for it include FE with a separate missing category
qui tab hhincome, missing gen(hhh) 
gen poor=hhincome<4 if hhincome~=.
gen liberal=policyview>3 if policyview~=. 
gen conservative = policyview<=2 if policyview~=. 

# delimit ;

eststo clear ;

local j 0 ;
foreach var of varlist obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student { ;
local ++j ;
eststo `var': reg followup `var' if inc_mill~=.   ;
local varlab: variable label `var' ; 
local estno "est`j'" ;
local relabel `"`relabel' `estno' "`varlab'""' ;
local beta=_b[`var'] ;
estadd scalar beta=`beta' ;
local obsvector=`"`obsvector' "`obs'""' ;
local titlevector=`"`titlevector' "`var'""' ;

di `"`titlevector'" ;

****Now, calculate p-value ;
local pval=2*ttail(e(df_r), abs(_b[`var']/_se[`var'])) ;
estadd scalar pvalue =  `pval' ;
*estadd scalar beta = _b[`var'] ;


} ;

esttab , cells(none) stats(beta pvalue) label mtitles(`"titlevector"') ;
matrix list r(stats) ;

***** ;
matrix C = r(stats) ;
eststo clear ;
local rnames : rownames C ;
di `"`rnames'"' ;
local models : colnames C ;
local models : list uniq models ;
local i 0 ;
foreach name of local rnames { ;
    local ++i ;
    local j 0 ;
    capture matrix drop b ;
    * capture matrix drop se ;
    foreach model of local models { ;
        local ++j ;
        di C[`i', `j'] ;
        matrix tmp = C[`i', `j'] ;
        if tmp[1,1]<. { ;
            matrix colnames tmp = `model' ;
            matrix b = nullmat(b), tmp ;
            matrix tmp[1,1] = C[`i', 3*`j'-1] ;
            * matrix se = nullmat(se), tmp ;
        } ;
    } ;
    ereturn post b ;
    * quietly estadd matrix se ;
    eststo `name' ;
} ;
****RELABEL VARS ;

foreach var of varlist black male education native age student married { ;
local temp=proper("`var'") ;
label var `var' "`temp'" ;
} ;
label var obama08 "Voted for Obama in 2008" ;
label var policyview "Liberal policy view" ;
label var hhincome "Household income" ;
label var nilf "Not in labor force" ;
label var unemp "Unemployed" ;
label var hisp "Hispanic" ;
label var fulltime "Employed full time" ;

esttab using selection_followup.tex, replace fragment booktabs varwidth(30) wrap cells(b(fmt(3)))
mlabels("Coefficient" "P-value", nonum lhs("Variable")) label noisily noobs nonumbers nogaps collabels(none) ;


eststo clear ;

local controls "obama08 age policyview hhincome educ male black hisp native unemp nilf student married fulltime"  ; 

label var treat "Treated"; 

foreach var of varlist inc_estate purpose_government trust_gov_yes ineq_vs { ;
eststo: areg `var' treat `controls'  if `var'_s2 != . , abs(state);
qui sum `var' if treat==0 ;
estadd scalar cmean=`r(mean)' ; 
eststo: areg `var'_s2 treat `controls' if `var' !=. , abs(state);
qui sum `var'_s2 if treat==0 `wgt' ;
estadd scalar cmean=`r(mean)' ;
estadd scalar cstdev = `r(sd)'; 
} ;

esttab using followup.tex, replace fragment booktabs keep(treat) label 
mgroups("Increase Estate Tax" "Govt scope" "Trust gov." "Ineq. v. serious", pattern(1 0 1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) 
span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se mtitles("First" "Follow-up" "First" "Follow-up" "First" "Follow-up" "First" "Follow-up" "First" "Follow-up") stats(cmean N, label("Control mean" "Obs.")) ;

*** Make a table for the appendix with all outcomes; 

eststo clear ;
foreach var of varlist ineq_vs ineq_inc_yes deserving_yes taxrate1_1  { ;
eststo: areg `var' treat `controls'  if `var'_s2 != . , abs(state);
qui sum `var' if treat==0 ;
estadd scalar cmean=`r(mean)' ; 
eststo: areg `var'_s2 treat `controls' if `var' !=. , abs(state);
qui sum `var'_s2 if treat==0 `wgt' ;
estadd scalar cmean=`r(mean)' ;
estadd scalar cstdev = `r(sd)'; 
} ;

esttab using followup1.tex, replace fragment booktabs keep(treat) label 
mgroups("Ineq. v. serious" "Ineq. inc." "Rich deserving" "Top tax rate" , pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) 
span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se mtitles("First" "Follow-up" "First" "Follow-up" "First" "Follow-up" "First" "Follow-up") stats(cmean N, label("Control mean" "Obs.")) ;

eststo clear ;
foreach var of varlist inc_mill inc_estate trust_gov_yes purpose_government { ;
eststo: areg `var' treat `controls'  if `var'_s2 != . , abs(state);
qui sum `var' if treat==0 ;
estadd scalar cmean=`r(mean)' ; 
eststo: areg `var'_s2 treat `controls' if `var' !=. , abs(state);
qui sum `var'_s2 if treat==0 `wgt' ;
estadd scalar cmean=`r(mean)' ;
estadd scalar cstdev = `r(sd)'; 
} ;

esttab using followup2.tex, replace fragment booktabs keep(treat) label 
mgroups("Mill. tax" "Estate tax" "Trust gov." "Govt scope", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) 
span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se mtitles("First" "Follow-up" "First" "Follow-up" "First" "Follow-up" "First" "Follow-up") stats(cmean N, label("Control mean" "Obs.")) ;

cap log close; 

exit; 
